@@ -427,7 +427,12 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
 	if freeze:
 		pretrained_model.trainable = False
 	else:
-		pretrained_model.trainable = True
+		#pretrained_model.trainable = True
+		for layer in pretrained_model.layers:
+			if not isinstance(layer, tf.keras.layers.BatchNormalization):
+				layer.trainable = True
+			else:
+				layer.trainable = False
 	
 	if model_name.startswith("EfficientNet"):
 		
